@@ -11,6 +11,11 @@ def generate_filepath(py_filename, output_folder, start_date, end_date, para_dic
         if key == 'code':
             if str(para).isdigit():
                 para = str(para).zfill(5)
+
+        if isinstance(para, float):
+            if para.is_integer():
+                para = int(para)
+
         save_name += f'{key}={str(para)}&'
 
     filepath = os.path.join(output_folder, f'{save_name[:-1]}.csv')
