@@ -62,8 +62,8 @@ class Plot:
                     dbc.Col(html.Div([
                         html.Div(style={'height': '10px', }),
                         sort_method_dropdown,
-                        html.Div(style={'height': '10px', }),
-                        subchart_dropdown,
+                        # html.Div(style={'height': '10px', }),
+                        # subchart_dropdown,
                         html.Div(style={'height': '10px', }),
                         html.Div(id='checklist-container',children=checkbox_div),
                         html.Div('---------------------------------------',style={'margin-left': '15px'}),
